pub trait Column {
type Output;
// Required method
fn get_column(&self, col: usize) -> Self::Output;
}Expand description
This type abstracts a matrix where you can get a copy of a column
Required Associated Types
Required Methods
Sourcefn get_column(&self, col: usize) -> Self::Output
fn get_column(&self, col: usize) -> Self::Output
Get a copy of a given column of a matrix
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".