pub trait ColumnRef: Column {
// Required method
fn get_column_ref(&self, col: usize) -> &Self::Output;
}Expand description
This type abstracts a matrix where you can get a reference of a column
Required Methods
Sourcefn get_column_ref(&self, col: usize) -> &Self::Output
fn get_column_ref(&self, col: usize) -> &Self::Output
Get a reference to a given column of a matrix
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".