NormalizeAssign

Trait NormalizeAssign 

pub trait NormalizeAssign {
    // Required method
    fn normalize_assign(&mut self);
}
This type abstracts a vector or other object that can be normalized to represent the same direction while having a length of 1

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors