Structs
- TVec2P
- A wrapper struct that is used to implement std140 packing for the underlying vector
- TVec3P
- A wrapper struct that is used to implement std140 packing for the underlying vector
- TVec4P
- A wrapper struct that is used to implement std140 packing for the underlying vector
Functions
- vector_
2_ packed_ f32 - Const fn for constructing a TVec2 in a const context
- vector_
2_ packed_ f64 - Const fn for constructing a TVec2 in a const context
- vector_
3_ packed_ f32 - Const fn for constructing a TVec3P in a const context
- vector_
3_ packed_ f64 - Const fn for constructing a TVec3P in a const context
- vector_
4_ packed_ f32 - Const fn for constructing a TVec4P in a const context
- vector_
4_ packed_ f64 - Const fn for constructing a TVec4P in a const context