pub trait NormalizeAssign {
// Required method
fn normalize_assign(&mut self);
}Expand description
This type abstracts a vector or other object that can be normalized to represent the same direction while having a length of 1
Required Methods
fn normalize_assign(&mut self)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".